<?php declare(strict_types=1);

namespace LidoNation\Adapayments;

class Application
{
    public Config $config;

    public array $paths = [];

    public function getPaths(): array
    {
        return $this->paths;
    }

    public function __construct()
    {
        $this->setupPaths();
        $this->config = new Config();
        $this->config->loadConfigurationFiles($this->paths['config_path'], $this->getEnvironment());
    }

    private function setupPaths(): void
    {
        $this->paths['env_file_path'] = __DIR__.'/../';
        $this->paths['env_file'] = $this->paths['env_file_path'].'.env';
        $this->paths['config_path'] = __DIR__.'/config/';
        $files = glob($this->paths['config_path'].'*');
    }

    public function getEnvironment(): array
    {
        $envFilePath = $this->paths['env_file'];
        $envFileContents = file_get_contents($envFilePath);

        $getenv = [];

        foreach (explode("\n", $envFileContents) as $line) {
            if (str_contains($line, '=')) {
                [$key, $value] = explode('=', $line);
                $getenv[$key] = $value;
            }
        }

        return $getenv;
    }

    /**
     * Get value for a key from a specific config file.
     *
     * @return mixed|null
     */
    public function getConfig(string $fileName, string $key): mixed
    {
        $filePath = $this->paths['config_path'].$fileName;

        if (file_exists($filePath)) {
            $configData = include $filePath;

            if (isset($configData[$key])) {
                return $configData[$key];
            }
        }

        return null;
    }
}
